@@ -76,10 +76,8 @@ namespace gbrainy.Clients.Classical.Dialogs
 			Copyright = Defines.COPYRIGHT;
 
 			Comments = Catalog.GetString ("A brain teaser game for fun and to keep your brain trained.");
-			Comments += "\n";
-			Comments += String.Format (Catalog.GetString ("gbrainy project web site: {0}"), "http://live.gnome.org/gbrainy");
-			Website = Defines.WEB_SITE;
-			WebsiteLabel = String.Format (Catalog.GetString ("You can also play on-line at {0}"), Defines.WEB_SITE);
+			Website = "http://live.gnome.org/gbrainy";
+			WebsiteLabel = Catalog.GetString ("gbrainy project web site");
 			TranslatorCredits = translators;
 			Artists = artists;
 			IconName = null;
