@@ -18,11 +18,11 @@
  */
 
 using System;
-using System.IO;
 using Gtk;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 using gbrainy.Clients.Classical.Widgets;
 
 namespace gbrainy.Clients.Classical.Dialogs
@@ -41,11 +41,15 @@ namespace gbrainy.Clients.Classical.Dialogs
 		[GtkBeans.Builder.Object] Gtk.ComboBox layout_combo;
 
 		BrowseFile file;
+		GameManager manager;
+		PdfExporter pdfExporter;
 		const int COLUMN_VALUE = 1;
 		const int DEF_SIDEVALUE = 4;
 
-		public PdfExportDialog () : base ("PdfExportDialog.ui", "pdfexportbox")
+		public PdfExportDialog (GameManager manager, ITranslations translations) : base (translations, "PdfExportDialog.ui", "pdfexportbox")
 		{
+			pdfExporter = new PdfExporter (translations);
+			this.manager = manager;
 			games_spinbutton.Value = 10;
 			checkbox_logic.Active = checkbox_calculation.Active = checkbox_verbal.Active = true;
 
@@ -87,7 +91,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			layout_combo.PackStart (layout_cell, true);
 			layout_combo.SetCellDataFunc (layout_cell, ComboBoxCellFunc);
 
-			int [] per_side = PdfExporter.PagesPerSide;
+			int [] per_side = pdfExporter.PagesPerSide;
 
 			for (int i = 0; i < per_side.Length; i++)
 				layout_store.AppendValues (per_side[i].ToString (), per_side[i]);
@@ -147,23 +151,24 @@ namespace gbrainy.Clients.Classical.Dialogs
 		void GeneratePdf (GameSession.Types types, int num_games, int gamespage, GameDifficulty difficulty, bool colorblind, string filename)
 		{
 			Game [] games;
-			GameManager gm;
+			GameSession session;
 			string msg;
 			MessageType msg_type;
 
 			games = new Game [num_games];
-			gm = new GameManager ();
-			gm.ColorBlind = colorblind;
-			gm.Difficulty = difficulty;
-			GtkClient.GameManagerPreload (gm);
-			gm.GameType = types;
+			session = new GameSession (Translations);
+			session.GameManager = manager;
+			session.PlayList.ColorBlind = colorblind;
+			session.PlayList.Difficulty = difficulty;
+			session.PlayList.GameType = types;
 
 			for (int n = 0; n < num_games; n++)
 			{
-				 games [n] = gm.GetPuzzle ();
+				games [n] = session.PlayList.GetPuzzle ();
+				games [n].Translations = Translations;
 			}
 
-			if (PdfExporter.GeneratePdf (games, gamespage, filename) == true) {
+			if (pdfExporter.GeneratePdf (games, gamespage, filename) == true) {
 				msg = Catalog.GetString ("The PDF file has been exported correctly.");
 				msg_type = MessageType.Info;
 			} else {
