@@ -17,10 +17,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using System;
-using System.ComponentModel;
-
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Core.Main
 {
@@ -37,7 +33,7 @@ namespace gbrainy.Core.Main
 		public double Y { get; set; }
 		public MouseEventType EventType { get; set; }
 
-		public MouseEventArgs (double x, double y, MouseEventType event_type)
+		public MouseEventArgs (double x, double y, MouseEventType event_type) : this ()
 		{
 			X = x;
 			Y = y;
