@@ -43,6 +43,7 @@ namespace gbrainy.Core.Main
 		public const string EnglishKey = "English";
 		public const string EnglishVersionKey = "EnglishVersion";
 		public const string LoadPlugginsKey = "LoadExtensions";
+		public const string SoundsKey = "Sounds";
 
 		static Preferences ()
 		{
@@ -141,6 +142,7 @@ namespace gbrainy.Core.Main
 			defaults.Add (EnglishVersionKey, string.Empty);
 			defaults.Add (EnglishKey, false.ToString ());
 			defaults.Add (LoadPlugginsKey, false.ToString ());
+			defaults.Add (SoundsKey, true.ToString ());
 		}
 
 		public static void Load ()
