@@ -42,6 +42,9 @@ namespace gbrainy.Core.Platform
 		[DllImport("libgtk-win32-2.0-0.dll")]
 		static extern unsafe bool gtk_show_uri(IntPtr screen, IntPtr uri, uint timestamp, out IntPtr error);
 
+		[DllImport ("libcanberra-gtk.so.0")]
+		static extern void ca_gtk_play_for_widget (IntPtr widget, uint id, string name1, string prop1, string name2, string prop2, IntPtr nil);
+
 		/* Taken from locale.h  */
 		[StructLayout (LayoutKind.Sequential,  Pack = 1, Size = 68)]
 		struct lconv
@@ -104,13 +107,35 @@ namespace gbrainy.Core.Platform
 
 		public static unsafe bool ShowUri (Gdk.Screen screen, string uri, uint timestamp)
 		{
-			IntPtr native_uri = GLib.Marshaller.StringToPtrGStrdup (uri);
-			IntPtr error = IntPtr.Zero;
-			bool raw_ret = gtk_show_uri(screen == null ? IntPtr.Zero : screen.Handle, native_uri, timestamp, out error);
-			bool ret = raw_ret;
-			GLib.Marshaller.Free (native_uri);
-			if (error != IntPtr.Zero) throw new GLib.GException (error);
-			return ret;
+
+			bool rslt = false;
+
+			try {
+				IntPtr native_uri = GLib.Marshaller.StringToPtrGStrdup (uri);
+				IntPtr error = IntPtr.Zero;
+				rslt = gtk_show_uri(screen == null ? IntPtr.Zero : screen.Handle, native_uri, timestamp, out error);
+				GLib.Marshaller.Free (native_uri);
+
+				if (error != IntPtr.Zero) 
+					throw new GLib.GException (error);
+			}
+
+			catch (Exception e) {
+				Console.WriteLine ("Unix.ShowUri. Error {0}", e);
+			}
+
+			return rslt;
+		}
+
+		public static void PlaySound(IntPtr widget, string filename)
+		{
+			try {
+				ca_gtk_play_for_widget (widget, 0, "media.name", filename,
+					"media.filename", filename,  IntPtr.Zero);
+			}
+			catch (Exception e) {
+				Console.WriteLine ("Unix.PlaySound. Error {0}", e);
+			}
 		}
 	}
 }
