@@ -18,7 +18,6 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 
@@ -29,7 +28,7 @@ namespace gbrainy.Games.Calculation
 		int number_a, number_b, ratio_a, ratio_b;
 
 		public override string Name {
-			get {return Catalog.GetString ("Ratio");}
+			get {return Translations.GetString ("Ratio");}
 		}
 
 		public override GameTypes Type {
@@ -39,32 +38,20 @@ namespace gbrainy.Games.Calculation
 		public override string Question {
 			get {
 				return String.Format (
-					Catalog.GetString ("Two numbers sum {0} and have a ratio of {1} to {2}. Which are these numbers? Answer using two numbers (e.g.: 1 and 2)."), 
+					Translations.GetString ("Which two numbers have a sum of {0} and have a ratio of {1} to {2}? Answer using two numbers (e.g.: 1 and 2)."), 
 					number_a + number_b, ratio_a, ratio_b);
 			}
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Catalog.GetString ("The second number is calculated by multiplying the first by {0} and dividing it by {1}."),
-					ratio_a, ratio_b);
+				return String.Format (Translations.GetString ("The second number can be calculated by multiplying the first number by {0} and dividing it by {1}."),
+					ratio_b, ratio_a);
 			}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("A ratio specifies a proportion between two numbers. A ratio a:b means that for every 'a' parts you have 'b' parts.");}
-		}
-
-		public override GameAnswerCheckAttributes CheckAttributes {
-			get { return GameAnswerCheckAttributes.Trim | GameAnswerCheckAttributes.MatchAll; }
-		}
-
-		public override string AnswerCheckExpression {
-			get { return "[0-9]+"; }
-		}
-
-		public override string AnswerValue {
-			get { return String.Format (Catalog.GetString ("{0} and {1}"), number_a, number_b); }
+			get { return Translations.GetString ("A ratio specifies a proportion between two numbers. A ratio of a:b means that for every 'a' parts you have 'b' parts.");}
 		}
 
 		protected override void Initialize ()
@@ -93,7 +80,10 @@ namespace gbrainy.Games.Calculation
 			ratio_b = 3 + random.Next (random_max);
 			number_b = number_a / ratio_a * ratio_b;
 
-			right_answer = String.Format ("{0} | {1}", number_a, number_b);
+			Answer.Correct = String.Format ("{0} | {1}", number_a, number_b);
+			Answer.CheckExpression = "[0-9]+";
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MatchAll;
+			Answer.CorrectShow = String.Format (Translations.GetString ("{0} and {1}"), number_a, number_b);
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -105,10 +95,10 @@ namespace gbrainy.Games.Calculation
 			gr.SetPangoLargeFontSize ();
 
 			gr.MoveTo (x, DrawAreaY + 0.22);
-			gr.ShowPangoText (String.Format (Catalog.GetString ("x + y = {0}"), number_a + number_b));
+			gr.ShowPangoText (String.Format (Translations.GetString ("x + y = {0}"), number_a + number_b));
 		
 			gr.MoveTo (x, DrawAreaY + 0.44);
-			gr.ShowPangoText (String.Format (Catalog.GetString ("have a ratio of {0}:{1}"), ratio_a, ratio_b));
+			gr.ShowPangoText (String.Format (Translations.GetString ("have a ratio of {0}:{1}"), ratio_a, ratio_b));
 		}
 	}
 }
