@@ -19,7 +19,6 @@
 
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 
@@ -48,33 +47,23 @@ namespace gbrainy.Games.Logic
 		private double radian = Math.PI / 180;
 
 		public override string Name {
-			get {return Catalog.GetString ("Build a triangle");}
+			get {return Translations.GetString ("Build a triangle");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("Which three pieces can you use together to build a triangle? Answer using the three figure names, e.g.: {0}{1}{2}."),
-					GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2));}
+				Translations.GetString ("Which three pieces can you use together to build a triangle? Answer using the three figure names, e.g.: {0}{1}{2}."),
+					Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2));}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("The resulting triangle is isosceles.");}
-		}
-
-		public override GameAnswerCheckAttributes CheckAttributes {
-			get { return GameAnswerCheckAttributes.Trim | GameAnswerCheckAttributes.IgnoreCase | GameAnswerCheckAttributes.MatchAll | GameAnswerCheckAttributes.IgnoreSpaces; }
-		}
-
-		public override string AnswerCheckExpression {
-			get { return GetPossibleAnswersExpression ();}
-		}
-
-		public override string AnswerValue {
-			get { return answers[0] + answers[1] + answers[2]; }
+			get { return Translations.GetString ("The resulting triangle is isosceles.");}
 		}
 
 		protected override void Initialize ()
 		{
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MatchAll | GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
+
 			switch (CurrentDifficulty) {
 			case GameDifficulty.Easy:
 				total_figures = 6;
@@ -95,18 +84,20 @@ namespace gbrainy.Games.Logic
 			{
 				switch ((Figures) random_indices_answers[i]) {
 				case Figures.TriangleB:
-					answers[0] =  GetPossibleAnswer (i);
+					answers[0] = Answer.GetMultiOption (i);
 					break;
 				case Figures.TriangleC:
-					answers[1] =  GetPossibleAnswer (i);
+					answers[1] = Answer.GetMultiOption (i);
 					break;
 				case Figures.Square:
-					answers[2] =  GetPossibleAnswer (i);
+					answers[2] = Answer.GetMultiOption (i);
 					break;
 				}
 			}
 
-			right_answer = answers[0] + " | " + answers[1] + " | " + answers[2];
+			Answer.Correct = answers[0] + " | " + answers[1] + " | " + answers[2];
+			Answer.CheckExpression = Answer.GetMultiOptionsExpression ();
+			Answer.CorrectShow = answers[0] + answers[1] + answers[2];
 		}
 
 		private static void DrawFigure (CairoContextEx gr, double x, double y, Figures figure)
@@ -165,7 +156,7 @@ namespace gbrainy.Games.Logic
 			{
 				DrawFigure (gr, x, y, (Figures) random_indices_answers[i]);
 				gr.MoveTo (x, y + 0.13);
-				gr.ShowPangoText (GetPossibleFigureAnswer (i));
+				gr.ShowPangoText (Answer.GetFigureName (i));
 
 				if (i  == (total_figures / 2) - 1) {
 					y+= 0.30;
@@ -175,11 +166,11 @@ namespace gbrainy.Games.Logic
 					x+= space_figures;
 			}
 
-			if (DrawAnswer == false)
+			if (Answer.Draw == false)
 				return;
 
 			gr.MoveTo (DrawAreaX, y + 0.28);
-			gr.ShowPangoText (Catalog.GetString ("The triangle is:"));
+			gr.ShowPangoText (Translations.GetString ("The triangle is:"));
 			gr.Stroke ();
 		
 			x = DrawAreaX + 0.35;
