@@ -18,9 +18,9 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -37,7 +37,7 @@ namespace gbrainy.Games.Logic
 		private string question, rationale;
 
 		public override string Name {
-			get {return Catalog.GetString ("Count series");}
+			get {return Translations.GetString ("Count series");}
 		}
 
 		public override string Question {
@@ -59,20 +59,20 @@ namespace gbrainy.Games.Logic
 			switch (game_type)
 			{
 				case GameType.HowManyNines:
-					question = Catalog.GetString ("How many numbers '9' are required to represent the numbers between 10 to 100?");
-					right_answer = "19";
+					question = Translations.GetString ("How many numbers '9' are required to represent the numbers between 10 to 100?");
+					Answer.Correct = "19";
 					numbers = new short [] {19, 29, 39, 49, 59, 69, 79, 89, 90, 91, 92 , 93, 94, 95, 96, 97, 98, 99};
 					break;
 
 				case GameType.HowManyBiggerDigits:
-					question = Catalog.GetString ("How many two digit numbers occur where the first digit is larger than the second (e.g.: 20 and 21)?");
-					right_answer = "45";
+					question = Translations.GetString ("How many two digit numbers occur where the first digit is larger than the second (e.g.: 20 and 21)?");
+					Answer.Correct = "45";
 					numbers = new short [] {10, 20, 21, 30, 31, 32, 40, 41, 42, 43, 50, 51, 52, 53, 54, 60, 61, 62, 63, 64, 65, 70, 71, 72, 73, 74, 75, 76, 80, 81, 82, 83, 84, 85, 86, 87, 90, 91, 92, 93, 94, 95, 96, 97, 98};
 					break;
 
 				case GameType.HowManySmallerDigits:
-					question = Catalog.GetString ("How many two digit numbers occur where the first digit is smaller than the second (e.g.: 12 and 13)?");
-					right_answer = "36";
+					question = Translations.GetString ("How many two digit numbers occur where the first digit is smaller than the second (e.g.: 12 and 13)?");
+					Answer.Correct = "36";
 					numbers = new short [] {12, 13, 14, 15, 16, 17, 18, 19, 23, 24, 25, 26, 27, 28, 29, 34, 35, 36, 37, 38, 39, 45, 46, 47, 48, 49, 56, 57, 58, 59, 67, 68, 69, 78, 79, 89};
 					break;
 				default:
@@ -83,15 +83,15 @@ namespace gbrainy.Games.Logic
 			for (int i = 1; i < numbers.Length; i++)
 			{
 				// Translators: A sequence of numbers 1, 2, 3, etc.
-				rationale = string.Format (Catalog.GetString ("{0}, {1}"), rationale, numbers[i].ToString ());
+				rationale = string.Format (Translations.GetString ("{0}, {1}"), rationale, numbers[i].ToString ());
 			}
 
-			rationale = string.Format (Catalog.GetString ("The numbers are: {0}."), rationale);
+			rationale = string.Format (Translations.GetString ("The numbers are: {0}."), rationale);
 
 			if (game_type == GameType.HowManyNines) {
-				// Translators: Concadenating two strings (rationale of answer + extra information).
-				rationale = string.Format (Catalog.GetString ("{0} {1}"), rationale,
-					Catalog.GetString ("Notice that 99 contains two numbers '9'."));
+				// Translators: Concatenating two strings (rationale of answer + extra information).
+				rationale = string.Format (Translations.GetString ("{0} {1}"), rationale,
+					Translations.GetString ("Notice that 99 contains two numbers '9'."));
 			}				
 		}
 	}
