@@ -18,11 +18,11 @@
  */
 
 using Cairo;
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -110,7 +110,7 @@ namespace gbrainy.Games.Logic
 		};
 
 		public override string Name {
-			get {return Catalog.GetString ("Larger shape");}
+			get {return Translations.GetString ("Larger shape");}
 		}
 
 		public override bool UsesColors {
@@ -119,13 +119,14 @@ namespace gbrainy.Games.Logic
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("Which larger shape can you make combining the first two figures? Answer {0}, {1}, {2} or {3}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
+				Translations.GetString ("Which larger shape can you make combining the first two figures? Answer {0}, {1}, {2} or {3}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		protected override void Initialize ()
 		{
-			palette = new ColorPalette ();
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
+			palette = new ColorPalette (Translations);
 
 			switch (random.Next (2)) {
 			case 0:
@@ -148,7 +149,7 @@ namespace gbrainy.Games.Logic
 			for (int i = 0; i < answers; i++)
 			{
 				if (random_indices[i] == ranswer) {
-					right_answer = GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					break;
 				}
 			}
@@ -179,7 +180,7 @@ namespace gbrainy.Games.Logic
 			};
 
 			// Answers
-			y += 0.3;
+			y += 0.28;
 			container = new HorizontalContainer (x, y, 0.8, 0.3);
 			AddWidget (container);
 	
@@ -187,7 +188,7 @@ namespace gbrainy.Games.Logic
 			{
 				drawable_area = new DrawableArea (container.Width / 2, 0.25);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 				container.AddChild (drawable_area);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
@@ -195,7 +196,7 @@ namespace gbrainy.Games.Logic
 					int n = (int) e.Data;
 					DrawPossibleAnswer (e.Context, 0.12, 0.03, answer, random_indices [n], n);
 
-					e.Context.DrawTextCentered (drawable_area.Width / 2, 0.22, GetPossibleFigureAnswer (n));
+					e.Context.DrawTextCentered (drawable_area.Width / 2, 0.22, Answer.GetFigureName (n));
 					e.Context.Stroke ();
 				};
 			}
@@ -207,7 +208,7 @@ namespace gbrainy.Games.Logic
 			{
 				drawable_area = new DrawableArea (container.Width / 2, 0.25);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 				container.AddChild (drawable_area);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
@@ -215,7 +216,7 @@ namespace gbrainy.Games.Logic
 					int n = (int) e.Data;
 					DrawPossibleAnswer (e.Context, 0.12, 0.03, answer, random_indices [n], n);
 
-					e.Context.DrawTextCentered (drawable_area.Width / 2, 0.22, GetPossibleFigureAnswer (n));
+					e.Context.DrawTextCentered (drawable_area.Width / 2, 0.22, Answer.GetFigureName (n));
 					e.Context.Stroke ();
 				};
 			}
@@ -299,7 +300,7 @@ namespace gbrainy.Games.Logic
 			base.Draw (gr, area_width, area_height, rtl);
 
 			gr.MoveTo (0.1, 0.3);
-			gr.ShowPangoText (Catalog.GetString ("Possible answers are:"));
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
 			gr.Stroke ();
 		}
 	}
