@@ -19,10 +19,10 @@
 
 using System;
 using Cairo;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -35,26 +35,27 @@ namespace gbrainy.Games.Logic
 		private const int answer_index = 4;
 
 		public override string Name {
-			get {return Catalog.GetString ("Pencil");}
+			get {return Translations.GetString ("Pencil");}
 		}
 
 		public override string Question {
-			get {return String.Format ( Catalog.GetString 
+			get {return String.Format ( Translations.GetString 
 				("Which of the following figures cannot be drawn without crossing any previous lines nor lifting the pencil? Answer {0}, {1}, {2}, {3} or {4}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3), GetPossibleAnswer (4));} 
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3), Answer.GetMultiOption (4));} 
 		}
 
 		protected override void Initialize ()
 		{
 			random_indices = new ArrayListIndicesRandom (figures);
 			random_indices.Initialize ();
-			right_answer = string.Empty;
+
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
 
 			for (int i = 0; i < random_indices.Count; i++) {
 				if (random_indices[i] != answer_index)
 					continue;
 			
-				right_answer = GetPossibleAnswer (i);
+				Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 				break;
 			}
 
@@ -86,7 +87,7 @@ namespace gbrainy.Games.Logic
 				drawable_area = new DrawableArea (box_size, figure_size);
 				drawable_area.SelectedArea = new Rectangle ((box_size - figure_size) / 2, 0, figure_size, figure_size);
 				drawable_area.Data = figure;
-				drawable_area.DataEx = GetPossibleAnswer (figure);
+				drawable_area.DataEx = Answer.GetMultiOption (figure);
 
 				switch (random_indices[figure]) {
 				case 0:
@@ -94,7 +95,7 @@ namespace gbrainy.Games.Logic
 					{
 						DrawTriangle (e.Context, (e.Width - figure_size) / 2, 0);
 						e.Context.DrawTextCentered (e.Width / 2, figure_size + text_offset, 
-							GetPossibleFigureAnswer ((int) e.Data));
+							Answer.GetFigureName ((int) e.Data));
 					};
 					break;
 				case 1:
@@ -102,7 +103,7 @@ namespace gbrainy.Games.Logic
 					{
 						DrawDiamon (e.Context, (e.Width - figure_size) / 2, 0);
 						e.Context.DrawTextCentered (e.Width / 2, figure_size + text_offset,
-							GetPossibleFigureAnswer ((int) e.Data));
+							Answer.GetFigureName ((int) e.Data));
 					};
 					break;
 				case 2:
@@ -110,7 +111,7 @@ namespace gbrainy.Games.Logic
 					{
 						DrawRectangleWithTriangles (e.Context, (e.Width - figure_size) / 2, 0);
 						e.Context.DrawTextCentered (e.Width / 2, figure_size + text_offset,
-							GetPossibleFigureAnswer ((int) e.Data));
+							Answer.GetFigureName ((int) e.Data));
 					};
 					break;
 				case 3:
@@ -118,7 +119,7 @@ namespace gbrainy.Games.Logic
 					{
 						DrawThreeTriangles (e.Context, (e.Width - figure_size) / 2, 0);
 						e.Context.DrawTextCentered (e.Width / 2, figure_size + text_offset,
-							GetPossibleFigureAnswer ((int) e.Data));
+							Answer.GetFigureName ((int) e.Data));
 					};
 					break;
 				case answer_index:
@@ -126,7 +127,7 @@ namespace gbrainy.Games.Logic
 					{
 						DrawRectangleWithCross (e.Context, (e.Width - figure_size) / 2, 0);
 						e.Context.DrawTextCentered (e.Width / 2, figure_size + text_offset,
-							GetPossibleFigureAnswer ((int) e.Data));
+							Answer.GetFigureName ((int) e.Data));
 					};
 					break;
 				}			
@@ -201,10 +202,5 @@ namespace gbrainy.Games.Logic
 			gr.LineTo (x, y + figure_size);
 			gr.Stroke ();
 		}
-
-		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
-		{
-			base.Draw (gr, area_width, area_height, rtl);
-		}
 	}
 }
