@@ -18,7 +18,6 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 
@@ -32,16 +31,16 @@ namespace gbrainy.Games.Logic
 		private const int figures = 3;
 
 		public override string Name {
-			get {return Catalog.GetString ("Squares and letters");}
+			get {return Translations.GetString ("Squares and letters");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("The letters around the squares follow a pattern. Which letter should replace the question mark in the last square?");} 
+			get {return Translations.GetString ("The letters around the squares follow a pattern. Which letter should replace the question mark in the last square?");} 
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Catalog.GetString ("Every letter is calculated by taking the alphabetical position of the previous character and adding {0} to it in order to get the position of the new letter."), step);
+				return String.Format (Translations.GetString ("Every letter is calculated by taking the alphabetical position of the previous character and adding {0} to it in order to get the position of the next letter."), step);
 			}
 		}
 
@@ -62,7 +61,7 @@ namespace gbrainy.Games.Logic
 				}				
 			}
 
-			right_answer = ToStr (characters[((figures - 1) * 4) + 3]);
+			Answer.Correct = ToStr (characters[((figures - 1) * 4) + 3]);
 			characters[((figures - 1) * 4) + 3] = '?';
 		}
 
