@@ -17,32 +17,31 @@
  * Boston, MA 02111-1307, USA.
  */
 
-
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 
+
 namespace gbrainy.Games.Logic
 {
 	public class PuzzleTriangles : Game
 	{
 		int type;
 		public override string Name {
-			get {return Catalog.GetString ("Triangles");}
+			get {return Translations.GetString ("Triangles");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("How many triangles of any size do you count in the figure below?");} 
+			get {return Translations.GetString ("How many triangles of any size do you count in the figure below?");} 
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("A triangle can be embedded inside another triangle.");}
+			get { return Translations.GetString ("A triangle can be embedded inside another triangle.");}
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Catalog.GetString ("The triangles are made by connecting the following points: {0}"),
+				return String.Format (Translations.GetString ("The triangles are made by connecting the following points: {0}"),
 					(type == 0) ? "bdc, dcf, dfg, abd, ade, edg, acg, abg, bcg, afg, ecg, acd, acf, ace, adg, cdg." : 
 					"dcf, ade, acg, afg, ecg, acd, acf, ace.");
 			}
@@ -56,9 +55,9 @@ namespace gbrainy.Games.Logic
 				type = random.Next (2);
 
 			if (type == 0)	
-				right_answer = "16";
+				Answer.Correct = "16";
 			else
-				right_answer = "8";
+				Answer.Correct = "8";
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -85,7 +84,7 @@ namespace gbrainy.Games.Logic
 			gr.LineTo (x + witdh, y);
 			gr.Stroke ();
 
-			if (DrawAnswer == false)
+			if (Answer.Draw == false)
 				return;
 
 			// References
