@@ -19,10 +19,10 @@
 
 using System;
 using Cairo;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Memory
 {
@@ -33,10 +33,13 @@ namespace gbrainy.Games.Memory
 			public Type type;
 			public object obj;
 
-			public Indication (Type type, object obj)
+			private ITranslations Translations {get; set;}
+
+			public Indication (ITranslations translations, Type type, object obj)
 			{
 				this.type = type;
 				this.obj = obj;
+				Translations = translations;
 			}
 
 			public enum Type
@@ -127,22 +130,22 @@ namespace gbrainy.Games.Memory
 			{
 				switch (type) {
 				case Indication.Type.Start:
-					return String.Format (Catalog.GetString ("Start at point number {0}"), (int) obj);
+					return String.Format (Translations.GetString ("Start at point number {0}"), (int) obj);
 				case Indication.Type.Turn: {
 					switch ((TurnDirection) obj) {
 					case TurnDirection.Right:
-						return Catalog.GetString ("Move right");
+						return Translations.GetString ("Move right");
 					case TurnDirection.Left:
-						return Catalog.GetString ("Move left");
+						return Translations.GetString ("Move left");
 					case TurnDirection.Up:
-						return Catalog.GetString ("Move up");
+						return Translations.GetString ("Move up");
 					case TurnDirection.Down:
-						return Catalog.GetString ("Move down");
+						return Translations.GetString ("Move down");
 					}
 					break;
 				}
 				case Indication.Type.End:
-					return String.Format (Catalog.GetString ("End at point {0}"), obj);
+					return String.Format (Translations.GetString ("End at point {0}"), obj);
 				}
 				return null;
 			}
@@ -156,14 +159,14 @@ namespace gbrainy.Games.Memory
 		private int ans;
 
 		public override string Name {
-			get {return Catalog.GetString ("Memorize indications");}
+			get {return Translations.GetString ("Memorize indications");}
 		}
 
 		public override string MemoryQuestion {
 			get { 
 				return String.Format (
-					Catalog.GetString ("Which of the following graphics represent the indications previously given? Answer {0}, {1}, {2} or {3}."),
-					GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
+					Translations.GetString ("Which of the following graphics represents the indications previously given? Answer {0}, {1}, {2} or {3}."),
+					Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		protected override void Initialize ()
@@ -171,21 +174,23 @@ namespace gbrainy.Games.Memory
 			indications = new Indication [CurrentDifficulty == GameDifficulty.Easy ? 5 : 7];
 			Indication.TurnDirection second_turn = (Indication.TurnDirection) 2 +  random.Next (2);
 		
-			indications[0] = new Indication (Indication.Type.Start, 0);
-			indications[1] = new Indication (Indication.Type.Turn, random.Next (2)); // right or left
-			indications[2] = new Indication (Indication.Type.Turn, second_turn); // up or down
-			indications[3] = new Indication (Indication.Type.Turn, random.Next (2)); // right or left
+			indications[0] = new Indication (Translations, Indication.Type.Start, 0);
+			indications[1] = new Indication (Translations, Indication.Type.Turn, random.Next (2)); // right or left
+			indications[2] = new Indication (Translations, Indication.Type.Turn, second_turn); // up or down
+			indications[3] = new Indication (Translations, Indication.Type.Turn, random.Next (2)); // right or left
+
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
 
 			if (CurrentDifficulty==GameDifficulty.Easy) {
-				indications[4] = new Indication (Indication.Type.End, 1);		
+				indications[4] = new Indication (Translations, Indication.Type.End, 1);		
 			} else {
 				if (second_turn == Indication.TurnDirection.Up)
-					indications[4] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Up);
+					indications[4] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Up);
 				else
-					indications[4] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Down);
+					indications[4] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Down);
 
-				indications[5] = new Indication (Indication.Type.Turn, random.Next (2)); // right or left
-				indications[6] = new Indication (Indication.Type.End, 1);
+				indications[5] = new Indication (Translations, Indication.Type.Turn, random.Next (2)); // right or left
+				indications[6] = new Indication (Translations, Indication.Type.End, 1);
 			}
 		
 			indications_wrongA = CopyAnswer ();
@@ -193,33 +198,33 @@ namespace gbrainy.Games.Memory
 			indications_wrongC = CopyAnswer ();
 
 			if ((Indication.TurnDirection) indications[3].obj == Indication.TurnDirection.Right) {
-				indications_wrongA[3] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Left);
+				indications_wrongA[3] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Left);
 			}
 			else {
-				indications_wrongA[3] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Right);
+				indications_wrongA[3] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Right);
 			}
 
 			if (CurrentDifficulty == GameDifficulty.Easy) {
 				if ((Indication.TurnDirection) indications[2].obj == Indication.TurnDirection.Up) {
-					indications_wrongB[2] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Down);
+					indications_wrongB[2] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Down);
 				}
 				else {
-					indications_wrongB[2] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Up);
+					indications_wrongB[2] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Up);
 				}
 			} else {
 				if ((Indication.TurnDirection) indications[5].obj == Indication.TurnDirection.Right) {
-					indications_wrongB[5] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Left);
+					indications_wrongB[5] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Left);
 				}
 				else {
-					indications_wrongB[5] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Right);
+					indications_wrongB[5] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Right);
 				}
 			}
 
 			if ((Indication.TurnDirection) indications[1].obj == Indication.TurnDirection.Right) {
-				indications_wrongC[1] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Left);
+				indications_wrongC[1] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Left);
 			}
 			else {
-				indications_wrongC[1] = new Indication (Indication.Type.Turn, Indication.TurnDirection.Right);
+				indications_wrongC[1] = new Indication (Translations, Indication.Type.Turn, Indication.TurnDirection.Right);
 			}
 		
 			base.Initialize ();
@@ -229,7 +234,7 @@ namespace gbrainy.Games.Memory
 
 			for (int i = 0; i < answers.Count; i++) {
 				if (answers [i] == 0) {
-					right_answer = GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					ans = i;
 					break;
 				}
@@ -245,14 +250,14 @@ namespace gbrainy.Games.Memory
 				container.AddChild (drawable_area);
 				drawable_area.SelectedArea = new Rectangle (0, 0, 0.45, 0.3);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
 					int n = (int) e.Data;
 
 					DrawPossibleAnswers (e.Context, 0.2, 0.1, WhichAnswer (answers[n]));
 					e.Context.MoveTo (0.2, 0.12 + 0.2);
-					e.Context.ShowPangoText (GetPossibleFigureAnswer (n));
+					e.Context.ShowPangoText (Answer.GetFigureName (n));
 				};
 			}
 
@@ -266,14 +271,14 @@ namespace gbrainy.Games.Memory
 				container.AddChild (drawable_area);
 				drawable_area.SelectedArea = new Rectangle (0, 0, 0.45, 0.3);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
 					int n = (int) e.Data;
 
 					DrawPossibleAnswers (e.Context, 0.2, 0.1, WhichAnswer (answers[n]));
 					e.Context.MoveTo (0.2, 0.12 + 0.2);
-					e.Context.ShowPangoText (GetPossibleFigureAnswer (n));
+					e.Context.ShowPangoText (Answer.GetFigureName (n));
 				};
 			}
 		}
@@ -282,7 +287,7 @@ namespace gbrainy.Games.Memory
 		{
 			Indication[] answer = new Indication [indications.Length];
 			for (int i = 0; i < indications.Length; i++)
-				answer[i] = new Indication (indications[i].type, indications[i].obj);
+				answer[i] = new Indication (Translations, indications[i].type, indications[i].obj);
 
 			return answer;
 		}
@@ -314,7 +319,7 @@ namespace gbrainy.Games.Memory
 		{
 			base.DrawObjectToMemorize (gr, area_width, area_height, rtl);
 
-			if (DrawAnswer == false) {
+			if (Answer.Draw == false) {
 				for (int i = 0; i < indications.Length; i++)
 				{
 					gr.MoveTo (0.3, 0.2 + i * 0.08);
@@ -330,7 +335,7 @@ namespace gbrainy.Games.Memory
 					}
 					DrawPossibleAnswers (gr, 0.7, 0.3, WhichAnswer (answers[ans]));
 					gr.MoveTo (0.7, 0.5);
-					gr.ShowPangoText (GetPossibleFigureAnswer (ans));
+					gr.ShowPangoText (Answer.GetFigureName (ans));
 					gr.Stroke ();
 			}
 		}
